@@ -1,8 +1,14 @@
 var a00687 =
 [
+    [ "ConstEdgeIterT", "a00115.html", null ],
+    [ "ConstFaceIterT", "a00116.html", null ],
+    [ "ConstHalfedgeIterT", "a00117.html", null ],
+    [ "ConstVertexIterT", "a00118.html", null ],
+    [ "EdgeIterT", "a00127.html", null ],
+    [ "FaceIterT", "a00141.html", null ],
     [ "GenericCirculator_CenterEntityFnsT", "a00153.html", null ],
-    [ "GenericCirculator_CenterEntityFnsT< Mesh, typename Mesh::VertexHandle >", "a00155.html", null ],
     [ "GenericCirculator_CenterEntityFnsT< Mesh, typename Mesh::FaceHandle >", "a00154.html", null ],
+    [ "GenericCirculator_CenterEntityFnsT< Mesh, typename Mesh::VertexHandle >", "a00155.html", null ],
     [ "GenericCirculator_DereferenciabilityCheckT", "a00156.html", null ],
     [ "GenericCirculator_DereferenciabilityCheckT< Mesh, typename Mesh::FaceHandle, typename Mesh::FaceHandle >", "a00157.html", null ],
     [ "GenericCirculator_DereferenciabilityCheckT< Mesh, typename Mesh::VertexHandle, typename Mesh::FaceHandle >", "a00158.html", null ],
@@ -10,13 +16,7 @@ var a00687 =
     [ "GenericCirculator_ValueHandleFnsT< Mesh, CenterEntityHandle, typename Mesh::FaceHandle >", "a00160.html", "a00160" ],
     [ "GenericCirculatorBaseT", "a00161.html", "a00161" ],
     [ "GenericCirculatorT", "a00162.html", "a00162" ],
-    [ "ConstVertexIterT", "a00118.html", null ],
-    [ "VertexIterT", "a00293.html", null ],
-    [ "ConstHalfedgeIterT", "a00117.html", null ],
+    [ "GenericIteratorT", "a00163.html", "a00163" ],
     [ "HalfedgeIterT", "a00168.html", null ],
-    [ "ConstEdgeIterT", "a00115.html", null ],
-    [ "EdgeIterT", "a00127.html", null ],
-    [ "ConstFaceIterT", "a00116.html", null ],
-    [ "FaceIterT", "a00141.html", null ],
-    [ "GenericIteratorT", "a00163.html", "a00163" ]
+    [ "VertexIterT", "a00293.html", null ]
 ];
\ No newline at end of file
