@@ -1,7 +1,7 @@
 /*===========================================================================*\
  *                                                                           *
  *                               OpenMesh                                    *
- *      Copyright (C) 2001-2012 by Computer Graphics Group, RWTH Aachen      *
+ *      Copyright (C) 2001-2014 by Computer Graphics Group, RWTH Aachen      *
  *                           www.openmesh.org                                *
  *                                                                           *
  *---------------------------------------------------------------------------* 
@@ -34,8 +34,8 @@
 
 /*===========================================================================*\
  *                                                                           *             
- *   $Revision: 829 $                                                         *
- *   $Date: 2013-06-03 11:00:42 +0200 (Mo, 03. Jun 2013) $                   *
+ *   $Revision: 990 $                                                         *
+ *   $Date: 2014-02-05 10:01:07 +0100 (Mi, 05 Feb 2014) $                   *
  *                                                                           *
 \*===========================================================================*/
 
@@ -369,7 +369,7 @@ decimate(const std::string &_ifname,
      float nv_before = float(mesh.n_vertices());
 
      timer.start();
-     int rc = 0;
+     size_t rc = 0;
      if (_opt.n_collapses < 0.0)
        rc = decimater.decimate_to( size_t(-_opt.n_collapses) );
      else if (_opt.n_collapses >= 1.0 || _opt.n_collapses == 0.0)
