@@ -1,7 +1,7 @@
 /*===========================================================================*\
  *                                                                           *
  *                               OpenMesh                                    *
- *      Copyright (C) 2001-2012 by Computer Graphics Group, RWTH Aachen      *
+ *      Copyright (C) 2001-2014 by Computer Graphics Group, RWTH Aachen      *
  *                           www.openmesh.org                                *
  *                                                                           *
  *---------------------------------------------------------------------------* 
@@ -34,8 +34,8 @@
 
 /*===========================================================================*\
  *                                                                           *             
- *   $Revision: 736 $                                                         *
- *   $Date: 2012-10-08 09:30:49 +0200 (Mo, 08. Okt 2012) $                   *
+ *   $Revision: 990 $                                                         *
+ *   $Date: 2014-02-05 10:01:07 +0100 (Mi, 05 Feb 2014) $                   *
  *                                                                           *
 \*===========================================================================*/
 
@@ -327,11 +327,11 @@ MeshViewerWidgetT<M>::draw_openmesh(const std::string& _draw_mode)
     for (; fIt!=fEnd; ++fIt)
     {
       fvIt = mesh_.cfv_iter(fIt.handle()); 
-      glArrayElement(fvIt.handle().idx());
+      glArrayElement(fvIt->idx());
       ++fvIt;
-      glArrayElement(fvIt.handle().idx());
+      glArrayElement(fvIt->idx());
       ++fvIt;
-      glArrayElement(fvIt.handle().idx());
+      glArrayElement(fvIt->idx());
     }
     glEnd();
     
@@ -363,11 +363,11 @@ MeshViewerWidgetT<M>::draw_openmesh(const std::string& _draw_mode)
     for (; fIt!=fEnd; ++fIt)
     {
       fvIt = mesh_.cfv_iter(fIt.handle()); 
-      glArrayElement(fvIt.handle().idx());
+      glArrayElement(fvIt->idx());
       ++fvIt;
-      glArrayElement(fvIt.handle().idx());
+      glArrayElement(fvIt->idx());
       ++fvIt;
-      glArrayElement(fvIt.handle().idx());
+      glArrayElement(fvIt->idx());
     }
     glEnd();
     
@@ -391,11 +391,11 @@ MeshViewerWidgetT<M>::draw_openmesh(const std::string& _draw_mode)
       glColor( fIt.handle() );
 
       fvIt = mesh_.cfv_iter(fIt.handle()); 
-      glArrayElement(fvIt.handle().idx());
+      glArrayElement(fvIt->idx());
       ++fvIt;
-      glArrayElement(fvIt.handle().idx());
+      glArrayElement(fvIt->idx());
       ++fvIt;
-      glArrayElement(fvIt.handle().idx());
+      glArrayElement(fvIt->idx());
     }
     glEnd();
     
