@@ -1,7 +1,7 @@
 /*===========================================================================*\
  *                                                                           *
  *                               OpenMesh                                    *
- *      Copyright (C) 2001-2012 by Computer Graphics Group, RWTH Aachen      *
+ *      Copyright (C) 2001-2014 by Computer Graphics Group, RWTH Aachen      *
  *                           www.openmesh.org                                *
  *                                                                           *
  *---------------------------------------------------------------------------* 
@@ -34,8 +34,8 @@
 
 /*===========================================================================*\
  *                                                                           *             
- *   $Revision: 736 $                                                         *
- *   $Date: 2012-10-08 09:30:49 +0200 (Mo, 08. Okt 2012) $                   *
+ *   $Revision: 990 $                                                         *
+ *   $Date: 2014-02-05 10:01:07 +0100 (Mi, 05 Feb 2014) $                   *
  *                                                                           *
 \*===========================================================================*/
 
@@ -289,28 +289,28 @@ get_active_cuts(const VHierarchyNodeHandle _node_handle,
 
   vl = VDPMMesh::InvalidVertexHandle;
   vr = VDPMMesh::InvalidVertexHandle;
-  
+
   for (vv_it=mesh_.vv_iter(vhierarchy_.vertex_handle(_node_handle)); 
-       vv_it; ++vv_it)
+      vv_it.is_valid(); ++vv_it)
   {
-    nnode_handle = mesh_.data(vv_it.handle()).vhierarchy_node_handle();
+    nnode_handle = mesh_.data(*vv_it).vhierarchy_node_handle();
     nnode_index = vhierarchy_.node_index(nnode_handle);
 
     if (vl == VDPMMesh::InvalidVertexHandle && 
-	vhierarchy_.is_ancestor(nnode_index, fund_lcut_index) == true)
-      vl = vv_it.handle();
+        vhierarchy_.is_ancestor(nnode_index, fund_lcut_index) == true)
+      vl = *vv_it;
 
     if (vr == VDPMMesh::InvalidVertexHandle && 
-	vhierarchy_.is_ancestor(nnode_index, fund_rcut_index) == true)
-      vr = vv_it.handle();
+        vhierarchy_.is_ancestor(nnode_index, fund_rcut_index) == true)
+      vr = *vv_it;
 
     /*if (vl == VDPMMesh::InvalidVertexHandle && nnode_index.is_ancestor_index(fund_lcut_index) == true)
-      vl = vv_it.handle();
+      vl = *vv_it;
     if (vr == VDPMMesh::InvalidVertexHandle && nnode_index.is_ancestor_index(fund_rcut_index) == true)
-      vr = vv_it.handle();*/
+      vr = *vv_it;*/
 
     if (vl != VDPMMesh::InvalidVertexHandle && 
-	vr != VDPMMesh::InvalidVertexHandle)
+        vr != VDPMMesh::InvalidVertexHandle)
       break;
   }
 }
@@ -539,11 +539,11 @@ open_vd_prog_mesh(const char* _filename)
 
    VDPMMesh::Point bbMin, bbMax;
 
-   bbMin = bbMax = mesh_.point(vIt);
+   bbMin = bbMax = mesh_.point(*vIt);
    for (; vIt!=vEnd; ++vIt)
    {
-      bbMin.minimize(mesh_.point(vIt));
-      bbMax.maximize(mesh_.point(vIt));
+      bbMin.minimize(mesh_.point(*vIt));
+      bbMax.maximize(mesh_.point(*vIt));
    }
   
   // set center and radius
