@@ -34,8 +34,8 @@
 
 /*===========================================================================*\
  *                                                                           *
- *   $Revision: 990 $                                                         *
- *   $Date: 2014-02-05 10:01:07 +0100 (Mi, 05 Feb 2014) $                   *
+ *   $Revision: 1075 $                                                         *
+ *   $Date: 2014-05-30 12:15:12 +0200 (Fr, 30 Mai 2014) $                   *
  *                                                                           *
 \*===========================================================================*/
 
@@ -175,8 +175,6 @@ bool
 _OFFWriter_::
 write_ascii(std::ostream& _out, BaseExporter& _be, Options _opt) const
 {
-  omlog() << "[OFFWriter] : write ascii file\n";
-
 
   unsigned int i, nV, nF;
   Vec3f v, n;
@@ -353,8 +351,6 @@ bool
 _OFFWriter_::
 write_binary(std::ostream& _out, BaseExporter& _be, Options _opt) const
 {
-  omlog() << "[OFFWriter] : write binary file\n";
-
 
   unsigned int i, nV, nF;
   Vec3f v, n;
@@ -495,7 +491,7 @@ binary_size(BaseExporter& _be, Options _opt) const
 {
   size_t header(0);
   size_t data(0);
-  size_t _3longs(3*sizeof(long));
+
   size_t _3floats(3*sizeof(float));
   size_t _3ui(3*sizeof(unsigned int));
   size_t _4ui(4*sizeof(unsigned int));
@@ -504,6 +500,8 @@ binary_size(BaseExporter& _be, Options _opt) const
     return 0;
   else
   {
+    size_t _3longs(3*sizeof(long));
+
     header += 11;                             // 'OFF BINARY\n'
     header += _3longs;                        // #V #F #E
     data   += _be.n_vertices() * _3floats;    // vertex data
