@@ -350,10 +350,6 @@ TEST_F(OpenMeshIterators, HalfedgeIterSkipping) {
   EXPECT_EQ(8u, mesh_.n_vertices() )   << "Wrong number of vertices";
   EXPECT_EQ(12u, mesh_.n_faces() )     << "Wrong number of faces";
 
-
-  // Run over all halfedges
-  unsigned int heCounter = 0;
-
   mesh_.request_face_status();
   mesh_.request_vertex_status();
   mesh_.request_halfedge_status();
@@ -550,10 +546,6 @@ TEST_F(OpenMeshIterators, HalfedgeIterSkippingLowLevel) {
   EXPECT_EQ(8u, mesh_.n_vertices() )   << "Wrong number of vertices";
   EXPECT_EQ(12u, mesh_.n_faces() )     << "Wrong number of faces";
 
-
-  // Run over all halfedges
-  unsigned int heCounter = 0;
-
   mesh_.request_face_status();
   mesh_.request_vertex_status();
   mesh_.request_halfedge_status();
